pub enum ServerConfigError {
Io(String),
Decode(String),
MissingField {
field: &'static str,
},
MissingCredential {
field: &'static str,
env: &'static str,
},
InvalidField {
field: &'static str,
reason: String,
},
}Variants
Io(String)
Decode(String)
MissingField
MissingCredential
A store credential absent from the file and from the environment variable that can stand in for it.
InvalidField